---
title: 관리자 콘솔 로그인이 안될 땐 어떻게 하나요?
category: 자주 묻는 질문 (일반 문의) > 관리자콘솔 > 관리자콘솔 문의
seo:
  title: 관리자 콘솔 로그인이 안될 땐 어떻게 하나요?
  description: 포트원 관리자콘솔 로그인 관련 문제가 발생한 경우 체크하실 사항을 안내드립니다.
  keywords:
    - 관리자콘솔
tags:
  - 관리자콘솔
pgCompanies:
  - 공통
datetime: 2024-01-25T15:00:00.000Z
---

#### **포트원 계정으로 메일 수신이 `가능`한 경우**

- [포트원 관리자콘솔↗ ](https://admin.portone.io/auth/signin) > 비밀번호 재설정 > 메일로 비밀번호 재설정 링크 수신 후 변경가능

#### **포트원 계정으로 메일 수신이 `불가능`한 경우**

아래 정보를 포트원 고객지원팀(<cs@portone.io>)으로 전달하신 후 강제로 포트원 메일주소를 변경합니다.\
(변경된 메일주소로 비밀번호 재설정링크 수신하여 변경가능)

- 상호명 :
- 사업자번호 :
- 대표자명 :
- 대표자 생년월일 :
- 고객사 식별코드 :
- 이용하시는 결제대행사(PG사) / 상점아이디 :
